pub enum ContainerError {
Common(CommonError),
Image(String),
Volume(String),
Runtime(String),
LockPoisoned,
}Expand description
Errors that can occur during container operations.
Variants
Common(CommonError)
Common errors shared across ArcBox crates.
Image(String)
Image error.
Volume(String)
Volume error.
Runtime(String)
Runtime error.
LockPoisoned
Internal lock poisoned.
Implementations
Sourceimpl ContainerError
impl ContainerError
Sourcepub fn invalid_state(msg: impl Into<String>) -> Self
pub fn invalid_state(msg: impl Into<String>) -> Self
Creates a new invalid state error.
Sourcepub fn already_exists(resource: impl Into<String>) -> Self
pub fn already_exists(resource: impl Into<String>) -> Self
Creates a new already exists error.
Sourcepub const fn is_not_found(&self) -> bool
pub const fn is_not_found(&self) -> bool
Returns true if this is a not found error.
Sourcepub const fn is_invalid_state(&self) -> bool
pub const fn is_invalid_state(&self) -> bool
Returns true if this is an invalid state error.